==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_context.js <==
/**
 * PopUp menu
 * Inherite: obj_hmenu
 **/
_me = obj_context.prototype;
function obj_context(){};

_me.__constructor = function(owner){

	this._owner = owner;

	//only one instance of contextmenu is allowed
/*
	if (_me.__oldinstance){
		if (_me.__oldinstance._destructed)
		    _me.__oldinstance = null;
		else
		try{
			document.onclick = _me.__oldinstance.__oldEvn || null;
			_me.__oldinstance._destruct();
		}
		catch(e){}
	}
	_me.__oldinstance = this;
*/

	var me = this;
	this.__oldEvn = document.onclick;

	document.onclick = function(){
		// destruct menu after click anywhere around
		me._destruct();
		//return original event handler
		document.onclick = me.__oldEvn || null;
		return true;
	};

	this._main.onclick = function(e){
		var e = e || window.event;

		// stop event propagation
		e.cancelBubble = true;
		if (e.stopPropagation) e.stopPropagation();

		// ELEMENT which caused event
		var elm = e.target || e.srcElement;

		if (elm.tagName!='A') return false;

		if (me._onclick) {
			// parse id
			var id = elm.id.substr(me._pathName.length+1);

			if (me.__idtable[id] && me.__idtable[id].disabled) return false;

			// call _onclick method
			me._onclick(e,elm,id,me.__idtable[id].arg || '');
		}

		//return original event handler
		document.onclick = me.__oldEvn || null;

		// destruct menu after click on any button
		me._destruct();
		return false;
	};
	
};

_me._onclick = function(e, elm, id, arg) {
	if (!arg) return;
	executeCallbackFunction(arg);
};

_me._place = function(x,y){

	var pos = getSize(this._main);

	//stupid MSIE fix
	if (pos.w>300) pos.w = 200;


	//HEIGHT
	var h = 0;
	if (window.innerHeight)
	    h = window.innerHeight;
	else
	if (window.document.body)
		h = window.document.body.clientHeight;

	if (h && y+pos.h>h)
		y = h - pos.h;

	//WIDTH
	var w = 0;
	if (window.innerWidth)
	    w = window.innerWidth;
	else
	if (window.document.body)
	    w = window.document.body.offsetWidth;

	if (w && x+pos.w>w)
		x = w - pos.w;


	this._main.style.top= y +'px';
	this._main.style.left= x +'px';
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_context.js <==
/**
 * PopUp menu
 * Inherite: obj_hmenu
 **/
_me = obj_context.prototype;
function obj_context(){};

_me.__constructor = function(owner){

	this._owner = owner;

	var me = this;

	this._add_destructor('__destructClickEvn');

	this.__click = function (){
		me._destruct();
		return true;
	};
	gui._obeyEvent('click',[this.__click]);
	
	this._main.onclick = function(e){
		var e = e || window.event;

		// stop event propagation
		e.cancelBubble = true;
		if (e.stopPropagation)
			e.stopPropagation();

		// ELEMENT which caused event
		var elm = e.target || e.srcElement;

		if (elm.tagName!='A') return false;

		if (me._onclick) {
			// parse id
			var id = elm.id.substr(me._pathName.length+1);

			if (me.__idtable[id] && me.__idtable[id].disabled) return false;

			// call _onclick method
			me._onclick(e,elm,id,me.__idtable[id].arg || '');
		}

		// destruct menu after click on any button
		me._destruct();
		return false;
	};
};

_me.__destructClickEvn = function(){
	//return original event handler
	gui._disobeyEvent('click',[this.__click]);
	this.__click = null;
};

_me._onclick = function(e, elm, id, arg) {
	if (!arg) return;
	executeCallbackFunction(arg);
};

_me._place = function(x,y){

	var pos = getSize(this._main);

	//stupid MSIE fix
	if (pos.w>300) pos.w = 200;


	//HEIGHT
	var h = 0;
	if (window.innerHeight)
	    h = window.innerHeight;
	else
	if (window.document.body)
		h = window.document.body.clientHeight;

	if (h && y+pos.h>h)
		y = h - pos.h;

	//WIDTH
	var w = 0;
	if (window.innerWidth)
	    w = window.innerWidth;
	else
	if (window.document.body)
	    w = window.document.body.offsetWidth;

	if (w && x+pos.w>w)
		x = w - pos.w;


	this._main.style.top= y +'px';
	this._main.style.left= x +'px';
};
